from pathlib import Path
from streamlit.components.v1 import declare_component
from streamlit_monaco_editor.flags import RELEASE

render_component = declare_component(
    "streamlit_monaco_editor",
    path=(Path(__file__).parent / "frontend/build").resolve()
)



from setuptools import setup
from pathlib import Path
import os

# generate file for RELEASE flag
with open((Path(__file__).parent / "streamlit_monaco_editor/flags.py").resolve(), "w") as f:
    f.write(f"RELEASE = {os.environ.get('RELEASE') == 'true'}\n")

setup()



from streamlit_monaco_editor.render import render_component

__version__ = "0.1.6"


def st_monaco(
    value="",
    height="200px",
    language="markdown",
    lineNumbers=True,
    minimap=False,
    theme="streamlit",
    key=None,
):
    return render_component(
        value=value,
        height=height,
        language=language,
        lineNumbers=lineNumbers,
        minimap=minimap,
        theme=theme,
        key=key,
    )
